@@ -211,7 +211,7 @@ $$ language plpgsql;
                 and updated_at < ( now() - (ttl_seconds * interval '1 second'))
                 ;
                 """,
-            {"from_status": (IN_PROGRESS,), "to_status": (HUNG,)},
+            {"from_status": (self.IN_PROGRESS,), "to_status": (self.HUNG,)},
         )
 
     # Update status of all jobs with from_status to to_status given they have time delta longer than given time
